@@ -55,6 +55,7 @@ copybutton_prompt_is_regexp = True
 # Mapping to external documentation
 intersphinx_mapping = {
     'audeer': ('https://audeering.github.io/audeer/', None),
+    'audfactory': ('https://audeering.github.io/audfactory/', None),
     'python': ('https://docs.python.org/3/', None),
 }
 
@@ -70,4 +71,7 @@ html_theme_options = {
     'logo_only': False,
     'footer_links': False,
 }
+html_context = {
+    'display_github': True,
+}
 html_title = title
